@@ -5,17 +5,17 @@
 
 from .bind import BindGenerator
 from .gnutls import GnuTLSGenerator
-from .java import JavaGenerator, JavaSystemGenerator
+from .java import JavaGenerator
+from .java import JavaSystemGenerator
 from .krb5 import KRB5Generator
 from .libreswan import LibreswanGenerator
 from .libssh import LibsshGenerator
 from .nss import NSSGenerator
-from .openssh import OpenSSHClientGenerator, OpenSSHServerGenerator
-from .openssl import (
-    OpenSSLConfigGenerator,
-    OpenSSLFIPSGenerator,
-    OpenSSLGenerator,
-)
+from .openssh import OpenSSHClientGenerator
+from .openssh import OpenSSHServerGenerator
+from .openssl import OpenSSLConfigGenerator
+from .openssl import OpenSSLGenerator
+from .openssl import OpenSSLFIPSGenerator
 
 __all__ = [
     'BindGenerator',
@@ -29,6 +29,6 @@ __all__ = [
     'OpenSSHClientGenerator',
     'OpenSSHServerGenerator',
     'OpenSSLConfigGenerator',
-    'OpenSSLFIPSGenerator',
     'OpenSSLGenerator',
+    'OpenSSLFIPSGenerator',
 ]
